package net.thecodersbreakfast.wickettips.presentation.wicket.behavior;

import org.apache.wicket.behavior.AttributeAppender;
import org.apache.wicket.model.AbstractReadOnlyModel;

/**
 * Attribute modifier that adds a different CSS class to the current table line,
 * depending on its index (even or odd). Its primary usage is to color every
 * other line to enhance readability. <br/>
 * Note that the CSS classes are <i>appended</i> to the existing ones, if any.
 * 
 * @author Olivier Croisier
 */
public class AlternateRowCssClassAttributeAppender extends AttributeAppender {

	public static final String CLASS_ATTRIBUTE = "class";
	public static final String CLASS_SEPARATOR = " ";

	// ================================================================================
	// Constructors
	// ================================================================================

	/**
	 * Constructor
	 * 
	 * @param item
	 *            The current line
	 * @param evenRowCssClass
	 *            The CSS class for the even lines
	 * @param oddRowCssClass
	 *            The CSS class for the odd lines
	 */
	public AlternateRowCssClassAttributeAppender(final int index, final String evenRowCssClass, final String oddRowCssClass) {
		super(AlternateRowCssClassAttributeAppender.CLASS_ATTRIBUTE, true, new AbstractReadOnlyModel<String>() {
			@Override
			public String getObject() {
				return (index % 2 == 0) ? evenRowCssClass : oddRowCssClass;
			}
		}, AlternateRowCssClassAttributeAppender.CLASS_SEPARATOR);
	}

}
