package net.thecodersbreakfast.wickettips.presentation.wicket.pages;

import java.util.Arrays;
import java.util.List;
import java.util.Locale;

import net.thecodersbreakfast.wickettips.presentation.wicket.behavior.AlternateRowCssClassAttributeAppender;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.model.AbstractReadOnlyModel;


/**
 * A sample page that demonstrates how to use the
 * AlternateRowCssClassAttributeAppender decorator.
 * 
 * @author Olivier Croisier
 */
public class StripedTablePage extends WebPage {

	/** A list of Locales */
	List<Locale> locales = Arrays.asList(Locale.getAvailableLocales());

	/**
	 * Constructor
	 */
	public StripedTablePage() {

		ListView<Locale> localesList = new ListView<Locale>("localesList", locales) {
			@Override
			protected void populateItem(final ListItem<Locale> item) {

				// Colorize each other line
				item.add(new AlternateRowCssClassAttributeAppender(item.getIndex(), "evenRow", "oddRow"));

				// Display the current locale's country and language
				final Locale loc = item.getModelObject();
				item.add(new Label("localeCountry", new AbstractReadOnlyModel<String>() {
					@Override
					public String getObject() {
						return loc.getDisplayCountry(loc);
					}
				}));
				item.add(new Label("localeLanguage", new AbstractReadOnlyModel<String>() {
					@Override
					public String getObject() {
						return loc.getDisplayLanguage(loc);
					}
				}));
			}

		};
		add(localesList);

	}

}
